@@ -7,7 +7,7 @@ use utf8;
 no warnings  'deprecated'; 
 
 use vars qw($DefaultClass %EXPORT_TAGS @EXPORT_OK @ISA %anker @TreeView %openArrays @caption $columns $clasic $ffirst $sort $border $orderby $size $style $orderbyColumn $prefix $bTrOver $desc %anker %ankerG $lang);
-$HTML::Menu::TreeView::VERSION = '1.16';
+$HTML::Menu::TreeView::VERSION = '1.17';
 @ISA                           = qw(Exporter);
 @HTML::Menu::TreeView::EXPORT_OK =
   qw(border Tree css columns jscript setStyle setDocumentRoot getDocumentRoot setSize setClasic clasic preload help folderFirst size style Style documentRoot loadTree saveTree  %anker %ankerG sortTree orderBy orderByColumn prefix setModern border TrOver desc language);
@@ -190,6 +190,11 @@ HTML::Menu::TreeView is a Modul to build an Html TreeView.
 
 =head1 Changes
 
+1.17
+    #defined @{@$tree[$i]->{subtree}} don't works with perl > 5.20
+    
+    so try test it with ref @$tree[$i]->{subtree}[0].
+
 1.14
     after a few years there a only a few bugfixes.
 
@@ -450,14 +455,14 @@ sub Tree
     }
     $r .=
 qq(<table border="0" cellpadding="0" cellspacing="0" summary="Tree" width="100%"><tr><td class="subtree"><table cellpadding="0" cellspacing="0"  align="left" border="0" summary="Tree" width="100%" class="treeview$size"><colgroup><col width="$size"/></colgroup>);
-    if (defined @caption) {
+    if ( @caption) {#defined
         my $class = $border ? "captionBorder$size" : "caption$size";
         $r .= qq(<tr><td class="$class"></td><td class="$class">$caption[0]</td></tr>);
     }
     $r .= $self->{tree} . '</table></td>';
     if (defined $self->{subtree}) {
         $r .= '<td class="subtree"><table align="left" border="0" cellpadding="0" cellspacing="0" summary="subTree" width="100%">';
-        if (defined @caption) {
+        if ( @caption) {#defined
             my $class = $border ? "captionBorder$size" : "caption$size";
             $r .= '<tr>';
             for (my $i = 1; $i <= $#caption; $i++) {
@@ -1137,9 +1142,9 @@ sub initTree
     for (my $i = 0; $i < @$tree; $i++) {
         next if ref @$tree[$i] ne "HASH";
         $length--;
-        no warnings  'deprecated';
-        if (defined @$tree[$i]) {
-             if (defined @{@$tree[$i]->{subtree}} && not defined @$tree[$i]->{empty}) {#a smalll fix, sorting closed folders will work with this change.
+#         no warnings  'deprecated';
+        if (defined @$tree[$i]) {#defined @{@$tree[$i]->{subtree}}
+             if ( ref @$tree[$i]->{subtree}[0] eq  "HASH"  and not defined @$tree[$i]->{empty}) {#a smalll fix, sorting closed folders will work with this change.
                 if ($length > 0) {
                     $self->appendFolder(@$tree[$i], \@{@$tree[$i]->{subtree}});
                 } elsif ($length eq 0) {
